@@ -3,6 +3,7 @@ import logging
 import zipfile
 import math
 import sys
+import tempfile
 from typing import List, Optional, Tuple
 from pathlib import Path
 
@@ -31,11 +32,11 @@ TOOLKIT_DIR = Path(__file__).parents[0].absolute()
 Segment = namedtuple('Segment', 'id aabb')
 
 
-def extract_depthmap(depthmap_fpath: str) -> Path:
+def extract_depthmap(depthmap_fpath: str, dest_dir: str) -> Path:
     """Extract depthmap from given file"""
     with zipfile.ZipFile(Path(depthmap_fpath), 'r') as zip_ref:
-        zip_ref.extractall(TOOLKIT_DIR)
-    return TOOLKIT_DIR / EXTRACTED_DEPTH_FILE_NAME
+        zip_ref.extractall(dest_dir)
+    return Path(dest_dir) / EXTRACTED_DEPTH_FILE_NAME
 
 
 def smoothen_depthmap_array(image_arr: np.ndarray) -> np.ndarray:
@@ -178,12 +179,13 @@ class Depthmap:
 
     @staticmethod
     def read_depthmap_data(depthmap_fpath):
-        path = extract_depthmap(depthmap_fpath)
-        with open(path, 'rb') as f:
-            header_line = f.readline().decode().strip()
-            width, height, depth_scale, max_confidence, device_pose = Depthmap.parse_header(header_line)
-            data = f.read()
-            f.close()
+        with tempfile.TemporaryDirectory() as tmpdirname:
+            path = extract_depthmap(depthmap_fpath, tmpdirname)
+            with open(path, 'rb') as f:
+                header_line = f.readline().decode().strip()
+                width, height, depth_scale, max_confidence, device_pose = Depthmap.parse_header(header_line)
+                data = f.read()
+                f.close()
         return width, height, data, depth_scale, max_confidence, device_pose, header_line
 
     @staticmethod
